@@ -743,7 +743,7 @@ class Zmon:
 # ONETIME-TOKENS
 ########################################################################################################################
 
-    @trace()
+    @trace()  # noqa: E301
     @logged
     def list_onetime_tokens(self) -> list:
         """
@@ -837,7 +837,13 @@ class Zmon:
         if 'id' in grafana_dashboard['dashboard'] and grafana_dashboard['dashboard']['id'] is not None:
             current_span.set_tag('grafana_dashboard_id', grafana_dashboard['dashboard']['id'])
 
-        resp = self.session.post(self.endpoint(GRAFANA), json=json.dumps(grafana_dashboard), timeout=self._timeout)
+        req = {'dashboard': grafana_dashboard['dashboard'],
+               'overwrite': True}
+
+        if 'folderId' in grafana_dashboard.get('meta', {}):
+            req['folderId'] = grafana_dashboard['meta']['folderId']
+
+        resp = self.session.post(self.endpoint(GRAFANA), json=json.dumps(req), timeout=self._timeout)
 
         return self.json(resp)
 
